@@ -7,7 +7,6 @@ from cqlengine.query import ModelQuerySet, DMLQuery, AbstractQueryableColumn
 from cqlengine.query import DoesNotExist as _DoesNotExist
 from cqlengine.query import MultipleObjectsReturned as _MultipleObjectsReturned
 
-
 class ModelDefinitionException(ModelException): pass
 
 
@@ -70,6 +69,52 @@ class QuerySetDescriptor(object):
         """
         raise NotImplementedError
 
+class TTLDescriptor(object):
+    """
+    returns a query set descriptor
+    """
+    def __get__(self, instance, model):
+        if instance:
+            # instance method
+            def ttl_setter(ts):
+                instance._ttl = ts
+                return instance
+            return ttl_setter
+
+        qs = model.__queryset__(model)
+
+        def ttl_setter(ts):
+            qs._ttl = ts
+            return qs
+
+        return ttl_setter
+
+    def __call__(self, *args, **kwargs):
+        raise NotImplementedError
+
+
+class ConsistencyDescriptor(object):
+    """
+    returns a query set descriptor if called on Class, instance if it was an instance call
+    """
+    def __get__(self, instance, model):
+        if instance:
+            def consistency_setter(consistency):
+                instance.__consistency__ = consistency
+                return instance
+            return consistency_setter
+
+        qs = model.__queryset__(model)
+
+        def consistency_setter(consistency):
+            qs._consistency = consistency
+            return qs
+
+        return consistency_setter
+
+    def __call__(self, *args, **kwargs):
+        raise NotImplementedError
+
 
 class ColumnQueryEvaluator(AbstractQueryableColumn):
     """
@@ -148,6 +193,8 @@ class BaseModel(object):
     class MultipleObjectsReturned(_MultipleObjectsReturned): pass
 
     objects = QuerySetDescriptor()
+    ttl = TTLDescriptor()
+    consistency = ConsistencyDescriptor()
 
     #table names will be generated automatically from it's model and package name
     #however, you can also define them manually here
@@ -179,10 +226,14 @@ class BaseModel(object):
     __queryset__ = ModelQuerySet
     __dmlquery__ = DMLQuery
 
+    __ttl__ = None
+    __consistency__ = None # can be set per query
+
     __read_repair_chance__ = 0.1
 
     def __init__(self, **values):
         self._values = {}
+        self._ttl = None
 
         for name, column in self._columns.items():
             value =  values.get(name, None)
@@ -356,7 +407,6 @@ class BaseModel(object):
         return cls.objects.get(*args, **kwargs)
 
     def save(self):
-
         # handle polymorphic models
         if self._is_polymorphic:
             if self._is_polymorphic_base:
@@ -366,7 +416,44 @@ class BaseModel(object):
 
         is_new = self.pk is None
         self.validate()
-        self.__dmlquery__(self.__class__, self, batch=self._batch).save()
+        self.__dmlquery__(self.__class__, self,
+                          batch=self._batch,
+                          ttl=self._ttl,
+                          consistency=self.__consistency__).save()
+
+        #reset the value managers
+        for v in self._values.values():
+            v.reset_previous_value()
+        self._is_persisted = True
+
+        return self
+
+    def update(self, **values):
+        for k, v in values.items():
+            col = self._columns.get(k)
+
+            # check for nonexistant columns
+            if col is None:
+                raise ValidationError("{}.{} has no column named: {}".format(self.__module__, self.__class__.__name__, k))
+
+            # check for primary key update attempts
+            if col.is_primary_key:
+                raise ValidationError("Cannot apply update to primary key '{}' for {}.{}".format(k, self.__module__, self.__class__.__name__))
+
+            setattr(self, k, v)
+
+        # handle polymorphic models
+        if self._is_polymorphic:
+            if self._is_polymorphic_base:
+                raise PolyMorphicModelException('cannot update polymorphic base model')
+            else:
+                setattr(self, self._polymorphic_column_name, self.__polymorphic_key__)
+
+        self.validate()
+        self.__dmlquery__(self.__class__, self,
+                          batch=self._batch,
+                          ttl=self._ttl,
+                          consistency=self.__consistency__).update()
 
         #reset the value managers
         for v in self._values.values():
@@ -379,6 +466,10 @@ class BaseModel(object):
         """ Deletes this instance """
         self.__dmlquery__(self.__class__, self, batch=self._batch).delete()
 
+    def get_changed_columns(self):
+        """ returns a list of the columns that have been updated since instantiation or save """
+        return [k for k,v in self._values.items() if v.changed]
+
     @classmethod
     def _class_batch(cls, batch):
         return cls.objects.batch(batch)
