@@ -8,10 +8,18 @@ from cqlengine.models import Model
 from cqlengine import columns
 
 class TestModel(Model):
+    id      = columns.UUID(primary_key=True, default=lambda:uuid4())
     count   = columns.Integer()
     text    = columns.Text(required=False)
     a_bool  = columns.Boolean(default=False)
 
+class TestModel(Model):
+    id      = columns.UUID(primary_key=True, default=lambda:uuid4())
+    count   = columns.Integer()
+    text    = columns.Text(required=False)
+    a_bool  = columns.Boolean(default=False)
+
+
 class TestModelIO(BaseCassEngTestCase):
 
     @classmethod
@@ -68,7 +76,6 @@ class TestModelIO(BaseCassEngTestCase):
         assert tm2.text is None
         assert tm2._values['text'].previous_value is None
 
-
     def test_a_sensical_error_is_raised_if_you_try_to_create_a_table_twice(self):
         """
         """
@@ -82,6 +89,7 @@ class TestMultiKeyModel(Model):
     count       = columns.Integer(required=False)
     text        = columns.Text(required=False)
 
+
 class TestDeleting(BaseCassEngTestCase):
 
     @classmethod
@@ -148,6 +156,14 @@ class TestUpdating(BaseCassEngTestCase):
         assert check.count is None
         assert check.text is None
 
+    def test_get_changed_columns(self):
+        assert self.instance.get_changed_columns() == []
+        self.instance.count = 1
+        changes = self.instance.get_changed_columns()
+        assert len(changes) == 1
+        assert changes == ['count']
+        self.instance.save()
+        assert self.instance.get_changed_columns() == []
 
 
 class TestCanUpdate(BaseCassEngTestCase):
